@@ -150,6 +150,7 @@
 #define HAVE_CUSERID 1
 #define HAVE_CXX_NEW 1
 /* #undef HAVE_DIRECTIO */
+#define HAVE_DLADDR 1
 #define HAVE_DLERROR 1
 #define HAVE_DLOPEN 1
 /* #undef HAVE_DOPRNT */
@@ -251,7 +252,7 @@
 #define HAVE_PUTENV 1
 #define HAVE_RE_COMP 1
 #define HAVE_REGCOMP 1
-#define HAVE_READDIR_R 1
+/* #undef HAVE_READDIR_R */
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_RENAME 1
@@ -407,7 +408,7 @@
 
 #define HAVE_MBSTATE_T 1
 
-#define MAX_INDEXES 64U
+#define MAX_INDEXES 64
 
 #define QSORT_TYPE_IS_VOID 1
 #define RETQSORTTYPE void
@@ -640,16 +641,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 30
+#define MYSQL_VERSION_PATCH 33
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.30"
+#define PACKAGE_STRING "MySQL Server 10.1.33"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.30"
-#define VERSION "10.1.30"
+#define PACKAGE_VERSION "10.1.33"
+#define VERSION "10.1.33"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
